@@ -7,8 +7,7 @@ import traceback
 import defusedxml.ElementTree as ET
 from os.path import expanduser
 
-import boto.s3
-import boto.sts
+import boto3
 from aws_access_util.constants import constants
 import logging
 from datetime import datetime
@@ -83,21 +82,13 @@ def saml2AWS(assertion, duration_seconds):
         principal_arn = awsroles[0].split(',')[1]
 
     # Use the assertion to get an AWS STS token using Assume Role with SAML
-    conn = boto.sts.connect_to_region(region)
+    client = boto3.client('sts')
     try:
-        token = conn.assume_role_with_saml(
-            role_arn,
-            principal_arn,
-            assertion,
-            duration_seconds=duration_seconds)
-    except boto.exception.BotoServerError as e:
-        track = traceback.format_exc()
-        print(track)
-        print('Failed to retrieve aws credentials : {e}'.format(e=e))
-        print('###################################################################')
-        print('#This may happen if you have specified an out of range duration   #')
-        print('###################################################################')
-        exit(1)
+        token = client.assume_role_with_saml(
+            RoleArn=role_arn,
+            PrincipalArn=principal_arn,
+            SAMLAssertion=assertion,
+            DurationSeconds=int(duration_seconds))
     except Exception as e:
         track = traceback.format_exc()
         print(track)
@@ -121,9 +112,9 @@ def saml2AWS(assertion, duration_seconds):
 
     config.set('saml', 'output', outputformat)
     # config.set('saml', 'region', region)
-    config.set('saml', 'aws_access_key_id', token.credentials.access_key)
-    config.set('saml', 'aws_secret_access_key', token.credentials.secret_key)
-    config.set('saml', 'aws_session_token', token.credentials.session_token)
+    config.set('saml', 'aws_access_key_id', token['Credentials']['AccessKeyId'])
+    config.set('saml', 'aws_secret_access_key', token['Credentials']['SecretAccessKey'])
+    config.set('saml', 'aws_session_token', token['Credentials']['SessionToken'])
 
     # Write the updated config file
     with open(filename, 'w+') as configfile:
@@ -139,7 +130,7 @@ def saml2AWS(assertion, duration_seconds):
               filename))
     print(
         'Note that it will expire at {0}.'.format(
-            token.credentials.expiration))
+            token['Credentials']['Expiration']))
     print('After this time, you may safely rerun this script to refresh '
           'your access key pair.')
     print(
